@@ -1,14 +1,14 @@
 package Org::Document;
 
 our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $VERSION = '0.52'; # VERSION
 
 use 5.010;
 use locale;
 use Log::Any::IfLOG '$log';
 use Moo;
 use experimental 'smartmatch';
-no if $] ge 5.021_006, warnings => "locale";
+no if $] >= 5.021_006, warnings => "locale";
 extends 'Org::Element';
 
 use List::MoreUtils qw(firstidx);
@@ -805,7 +805,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.51 of Org::Document (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.52 of Org::Document (from Perl distribution Org-Parser), released on 2016-11-06.
 
 =head1 SYNOPSIS
 
