@@ -1,13 +1,13 @@
 package Org::Element::Timestamp;
 
 our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $VERSION = '0.52'; # VERSION
 
 use 5.010;
 use locale;
 use utf8;
 use Moo;
-no if $] ge 5.021_006, warnings => "locale";
+no if $] >= 5.021_006, warnings => "locale";
 extends 'Org::Element';
 with 'Org::Element::InlineRole';
 
@@ -210,7 +210,7 @@ Org::Element::Timestamp - Represent Org timestamp
 
 =head1 VERSION
 
-This document describes version 0.51 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.52 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2016-11-06.
 
 =head1 DESCRIPTION
 
